@@ -1,6 +1,6 @@
 
 package Module::Spec::V1;
-$Module::Spec::V1::VERSION = '0.3.0';
+$Module::Spec::V1::VERSION = '0.4.0';
 # ABSTRACT: Load modules based on specifications V1
 use 5.010001;
 
@@ -82,14 +82,16 @@ sub _opts {
     my %opts = ( require => 1, %{ shift // {} } );
 
     my $v = $opts{require};
-    $opts{require} = ref $v eq 'CODE' ? $v : sub {$v};
+    $opts{require} = sub {$v}
+      unless ref $v eq 'CODE';
 
     return \%opts;
 }
 
 # Diagnostics:
 #  Can't locate Foo.pm in @INC (you may need to install the Foo module) (@INC contains:
-#  Carp version 2.3 required--this is only version 1.40
+#  Carp version 2.3 required--this is only version 1.40 at
+#  Foo2 does not define $Foo2::VERSION--version check failed at
 
 # try_module($spec)
 # try_module($spec, \%opts)
@@ -100,13 +102,19 @@ sub try_module {
 
     my ( $m, @v ) = _parse_module_spec( $_[-1] )
       or croak(qq{Can't parse $_[-1]});
-    eval {
-        _require_module($m) if $opts->{require}->( $m, @v );
-        $m->VERSION(@v) if @v;
-        1;
+    if ( $opts->{require}->( $m, @v ) ) {
+        eval { _require_module($m) };
+        if ($@) {
+            my $err = $@;
+            $err =~ /\ACan't locate\b/ ? return : die $err;
+        }
+    }
+    if (@v) {
+        eval { $m->VERSION(@v) };
+        return if $@;
+
+        # FIXME might ignore and eat non-load/non-version-check errors
     }
-      or
-      return;   # FIXME might ignore and eat non-load/non-version-check errors
     return wantarray ? ( $m, $m->VERSION ) : $m;
 }
 
@@ -191,7 +199,7 @@ sub croak {
 #pod
 #pod     require => 1    # default
 #pod     require => 0
-#pod     require => sub { my ($m, $v) = @_; ... }
+#pod     require => sub { my ($m, @v) = @_; ... }
 #pod
 #pod Controls whether the specified module should be C<require>d or not.
 #pod It can be given as a non-subroutine value, which gets
@@ -233,7 +241,7 @@ sub croak {
 #pod
 #pod     require => 1    # default
 #pod     require => 0
-#pod     require => sub { my ($m, $v) = @_; ... }
+#pod     require => sub { my ($m, @v) = @_; ... }
 #pod
 #pod Controls whether the specified module should be C<require>d or not.
 #pod It can be given as a non-subroutine value, which gets
@@ -247,6 +255,20 @@ sub croak {
 #pod
 #pod =back
 #pod
+#pod =head1 CAVEATS
+#pod
+#pod =over 4
+#pod
+#pod =item *
+#pod
+#pod Single quotes (C<'>) are not accepted as package separators.
+#pod
+#pod =item *
+#pod
+#pod Exceptions are not thrown from the perspective of the caller.
+#pod
+#pod =back
+#pod
 #pod =cut
 
 __END__
@@ -261,7 +283,7 @@ Module::Spec::V1 - Load modules based on specifications V1
 
 =head1 VERSION
 
-version 0.3.0
+version 0.4.0
 
 =head1 SYNOPSIS
 
@@ -326,7 +348,7 @@ These options are currently available:
 
     require => 1    # default
     require => 0
-    require => sub { my ($m, $v) = @_; ... }
+    require => sub { my ($m, @v) = @_; ... }
 
 Controls whether the specified module should be C<require>d or not.
 It can be given as a non-subroutine value, which gets
@@ -368,7 +390,7 @@ These options are currently available:
 
     require => 1    # default
     require => 0
-    require => sub { my ($m, $v) = @_; ... }
+    require => sub { my ($m, @v) = @_; ... }
 
 Controls whether the specified module should be C<require>d or not.
 It can be given as a non-subroutine value, which gets
@@ -382,6 +404,20 @@ with C<require> or false otherwise.
 
 =back
 
+=head1 CAVEATS
+
+=over 4
+
+=item *
+
+Single quotes (C<'>) are not accepted as package separators.
+
+=item *
+
+Exceptions are not thrown from the perspective of the caller.
+
+=back
+
 =head1 AUTHOR
 
 Adriano Ferreira <ferreira@cpan.org>
